elephant.test.test_pandas_bridge module — Elephant 0.5.0 documentation

# elephant.test.test_pandas_bridge module

Unit tests for the pandas bridge module.

class `elephant.test.test_pandas_bridge.` `ConvertValueSafeTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `test__convert_value_safe__bytes`()
  `test__convert_value_safe__float`()
  `test__convert_value_safe__numpy_float_scalar`()
  `test__convert_value_safe__numpy_int_scalar`()
  `test__convert_value_safe__numpy_str_scalar`()
  `test__convert_value_safe__numpy_unicode_scalar`()
  `test__convert_value_safe__quantity_scalar`()
  `test__convert_value_safe__str`()

class `elephant.test.test_pandas_bridge.` `EpochToDataframeTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `test__epoch_to_dataframe__noparents`()
  `test__epoch_to_dataframe__parents_childfirst`()
  `test__epoch_to_dataframe__parents_empty`()
  `test__epoch_to_dataframe__parents_parentfirst`()

class `elephant.test.test_pandas_bridge.` `EventToDataframeTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `test__event_to_dataframe__noparents`()
  `test__event_to_dataframe__parents_childfirst`()
  `test__event_to_dataframe__parents_empty`()
  `test__event_to_dataframe__parents_parentfirst`()

class `elephant.test.test_pandas_bridge.` `MultiEpochsToDataframeTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test__multi_epochs_to_dataframe__block_noparents`()
  `test__multi_epochs_to_dataframe__block_parents_childfirst`()
  `test__multi_epochs_to_dataframe__block_parents_parentfirst`()
  `test__multi_epochs_to_dataframe__dict_default`()
  `test__multi_epochs_to_dataframe__iter_default`()
  `test__multi_epochs_to_dataframe__list_noparents`()
  `test__multi_epochs_to_dataframe__list_parents_childfirst`()
  `test__multi_epochs_to_dataframe__list_parents_parentfirst`()
  `test__multi_epochs_to_dataframe__segment_default`()
  `test__multi_epochs_to_dataframe__single`()
  `test__multi_epochs_to_dataframe__tuple_default`()

class `elephant.test.test_pandas_bridge.` `MultiEventsToDataframeTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test__multi_events_to_dataframe__block_noparents`()
  `test__multi_events_to_dataframe__block_parents_childfirst`()
  `test__multi_events_to_dataframe__block_parents_parentfirst`()
  `test__multi_events_to_dataframe__dict_default`()
  `test__multi_events_to_dataframe__iter_default`()
  `test__multi_events_to_dataframe__list_noparents`()
  `test__multi_events_to_dataframe__list_parents_childfirst`()
  `test__multi_events_to_dataframe__list_parents_parentfirst`()
  `test__multi_events_to_dataframe__segment_default`()
  `test__multi_events_to_dataframe__single`()
  `test__multi_events_to_dataframe__tuple_default`()

class `elephant.test.test_pandas_bridge.` `MultiSpiketrainsToDataframeTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test__multi_spiketrains_to_dataframe__block_noparents`()
  `test__multi_spiketrains_to_dataframe__block_parents_childfirst`()
  `test__multi_spiketrains_to_dataframe__block_parents_parentfirst`()
  `test__multi_spiketrains_to_dataframe__dict_default`()
  `test__multi_spiketrains_to_dataframe__iter_default`()
  `test__multi_spiketrains_to_dataframe__list_noparents`()
  `test__multi_spiketrains_to_dataframe__list_parents_childfirst`()
  `test__multi_spiketrains_to_dataframe__list_parents_parentfirst`()
  `test__multi_spiketrains_to_dataframe__segment_default`()
  `test__multi_spiketrains_to_dataframe__single`()
  `test__multi_spiketrains_to_dataframe__tuple_default`()
  `test__multi_spiketrains_to_dataframe__unit_default`()

class `elephant.test.test_pandas_bridge.` `MultiindexFromDictTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `test__multiindex_from_dict`()

class `elephant.test.test_pandas_bridge.` `SliceSpiketrainTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `setUp`()
  `test_single_both`()
  `test_single_none`()
  `test_single_t_start`()
  `test_single_t_stop`()

class `elephant.test.test_pandas_bridge.` `SpiketrainToDataframeTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `test__spiketrain_to_dataframe__noparents`()
  `test__spiketrain_to_dataframe__parents_childfirst`()
  `test__spiketrain_to_dataframe__parents_empty`()
  `test__spiketrain_to_dataframe__parents_parentfirst`()

`elephant.test.test_pandas_bridge.` `assert_index_equal`(left, right)